/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view;

/**
 * The layout manager is responsible for laying out the diagram and painting it to the specified Graphics2D object.
 * This interface defines the contract for implemenations to follow.
 *
 * @author Pops
 * @author TCSDeveloper
 */
public interface LayoutManager {

    /**
     * This method is called by the DependencyRenderer to layout and print the diagram.
     * This method is provided the dependency to layout, the shape factory to retrieve
     * the shapes from and the Renderer that will be used
     *
     * @param dependency The dependency to layout
     * @param shapeFactory The shape factory to use
     * @param renderer The renderer that will be used
     * @throws NullPointerException if any parameter is null
     * @throws RendererException if some exception occurred while laying out the dependency diagram
     */
    void layout(Dependency dependency, ShapeFactory shapeFactory, DiagramRenderer render) throws RendererException;

}
