/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view;

import junit.framework.TestCase;
import java.io.File;

/**
 * Unit test cases for SVGRenderer.
 *
 * Testing of SVGRenderer verifies it can work separately for directory or file.
 *
 * @author TCSDeveloper
 */
public class SVGRendererUnitTests extends TestCase {

    /**
     * The directory to use.
     */
    private File directory = new File("test_files");

    /**
     * The file to use.
     */
    private File file = new File(directory, "unittest.svg");

    /**
     * The dependency to use.
     */
    private Dependency dependency = new Dependency("unittest");

    /**
     * The SVGRenderer instance to test.
     */
    private SVGRenderer renderer = null;

    /**
     * Create a new renderer for each test.
     */
    protected void setUp() {
        renderer = new SVGRenderer(file);
    }

    /**
     * Create instance with path.
     */
    public void testCreate_Path() {
        renderer = new SVGRenderer(file);
        assertEquals("Path mismatches.", file, renderer.getPath());
    }

    /**
     * Create instance with null path.
     */
    public void testCreate_NullPath() {
        try {
            new SVGRenderer(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) {
        }
    }

    /**
     * Test getPath().
     */
    public void testGetPath() {
        assertEquals("Path mismatches.", file, renderer.getPath());
    }

    /**
     * Test setPath().
     */
    public void testSetPath() {
        renderer.setPath(directory);
        assertEquals("Path mismatches.", directory, renderer.getPath());
    }

    /**
     * Test setPath() with null path.
     */
    public void testSetPath_NullPath() {
        try {
            renderer.setPath(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) {
        }
    }

    /**
     * Test getGraphics() with file path.
     *
     * @throws RendererException to JUnit.
     */
    public void testGetGraphics_FilePath() throws RendererException {
        renderer.setPath(file);
        RendererGraphics graphics = renderer.getGraphics(dependency);
        graphics.complete();
        graphics.dispose();

        File output = new File("test_files/unittest.svg");
        assertTrue("Output does not exist.", output.exists());
        output.delete();
    }

    /**
     * Test getGraphics() with directory path.
     *
     * @throws RendererException to JUnit.
     */
    public void testGetGraphics_DirectoryPath() throws RendererException {
        renderer.setPath(directory);
        RendererGraphics graphics = renderer.getGraphics(dependency);
        graphics.complete();
        graphics.dispose();

        File output = new File("test_files/unittest.svg");
        assertTrue("Output does not exist.", output.exists());
        output.delete();
    }

    /**
     * Test getGraphics() with null dependency.
     */
    public void testGetGraphics_NullDependency() {
        try {
            renderer.getGraphics(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) {
        }
    }

}
